@@ -16,6 +16,7 @@
 import logging
 
 from osc_lib.i18n import _
+from osc_lib import utils
 
 from tripleoclient import command
 from tripleoclient import constants
@@ -138,11 +139,19 @@ class UpdateRun(command.Command):
                                    'generated in '
                                    '~/tripleo-ansible-inventory.yaml')
                             )
+        parser.add_argument('--stack', dest='stack',
+                            help=_('Name or ID of heat stack '
+                                   '(default=Env: OVERCLOUD_STACK_NAME)'),
+                            default=utils.env('OVERCLOUD_STACK_NAME',
+                                              default='overcloud')
+                            )
+
         return parser
 
     def take_action(self, parsed_args):
         self.log.debug("take_action(%s)" % parsed_args)
         clients = self.app.client_manager
+        stack = parsed_args.stack
 
         # Run ansible:
         nodes = parsed_args.nodes
@@ -151,7 +160,7 @@ class UpdateRun(command.Command):
             nodes = None
         playbook = parsed_args.playbook
         inventory = oooutils.get_tripleo_ansible_inventory(
-            parsed_args.static_inventory, parsed_args.ssh_user)
+            parsed_args.static_inventory, parsed_args.ssh_user, stack)
         oooutils.run_update_ansible_action(self.log, clients, nodes, inventory,
                                            playbook, constants.UPDATE_QUEUE,
                                            constants.MINOR_UPDATE_PLAYBOOKS,
